@@ -1,6 +1,6 @@
 package Net::Google::CivicInformation;
 
-our $VERSION = '1.03';
+our $VERSION = '1.9901';
 
 use strict;
 use warnings;
@@ -46,7 +46,7 @@ __END__
 
 =head1 VERSION
 
-version 1.03
+version 1.9901
 
 =encoding utf8
 
@@ -56,8 +56,7 @@ Net::Google::CivicInformation - client for the Google Civic Information API
 
 =head1 DESCRIPTION
 
-Civic information (elected representatives, their contact information,
-jurisdictions, etc) for US addresses, provided via the Google Civic
+Civic information jurisdictions, etc) for US addresses, provided via the Google Civic
 Information API.
 
 You must obtain an API key (free) from Google to use this package. See
@@ -67,6 +66,8 @@ Do not use this module directly. Use one of the subclasses.
 
 =head1 SEE ALSO
 
+L<Net::Google::CivicInformation::Divisions>
+
 L<Net::Google::CivicInformation::Representatives>
 
 =head1 AUTHOR
